package Catmandu::Template;

our $VERSION = '0.14';

1;

__END__

=head1 NAME

Catmandu::Template - Catmandu modules for working with templates

=begin markdown

# STATUS

![Test status](https://github.com/LibreCat/Catmandu-RIS/actions/workflows/linux.yml/badge.svg)
[![Coverage](https://coveralls.io/repos/LibreCat/Catmandu-Template/badge.png?branch=master)](https://coveralls.io/r/LibreCat/Catmandu-Template)
[![CPANTS kwalitee](http://cpants.cpanauthors.org/dist/Catmandu-Template.png)](http://cpants.cpanauthors.org/dist/Catmandu-Template)

=end markdown

=head1 MODULES

=over

=item * L<Catmandu::Exporter::Template>

=item * L<Catmandu::Fix::template>

=back

=head1 AUTHOR

Nicolas Steenlant, C<< <nicolas.steenlant at ugent.be> >>

=head1 CONTRIBUTOR

Vitali Peil, C<< <vitali.peil at uni-bielefeld.de> >>

Jakob Voss, C<< <jakob.voss at gbv.de> >>

Patrick Hochstenbach, C<< <patrick.hochstenbach at ugent.be> >>

Nicolas Franck, C<< Nicolas.Franck at ugent.be >>

Debabrata Deka

=head1 LICENSE

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
